@@ -10,17 +10,17 @@ NULL
 #' @export
 Tg <- function(x = NULL,
                Pop = 1,
-               es = FALSE,
+               es = "none",
                plot = FALSE,
                ...,
                alternative = c("two.sided", "less", "greater"),
-               padjust = p.adjust.methods,
+               padjust = "none",
                letters = FALSE,
                digits = 4,
-               sig.level = 0.05) {
-  .Deprecated("t_greene")
-  # t-test for a data.frame -------------------------------------------------
-
+               CI = 0.95) {
+  if (!identical(Sys.getenv("TESTTHAT"), "true")) {
+    .Deprecated("t_greene")
+  }
   if (!(is.data.frame(x))) {
     stop("x should be a dataframe")
   }
@@ -42,17 +42,20 @@ Tg <- function(x = NULL,
   if (nrow(x) < 2) {
     stop("x should at least have 2 rows")
   }
-  x <- data.frame(x)
+  padjust <- match.arg(padjust, choices = p.adjust.methods)
+  x <- x %>%
+    drop_na() %>%
+    as.data.frame()
   x$Pop <- x[, Pop]
   if (length(dplyr::contains("-", vars = x$Pop)) != 0) {
     x$Pop <-
       gsub(
         x = x$Pop,
-        pattern = "-",
+        pattern = "[^[:alnum:]]",
         replacement = "_"
       )
   }
-  x$Pop <- factor(x$Pop)
+  x$Pop <- factor(x$Pop, levels = x$Pop)
   x$Pop <- droplevels(x$Pop)
   if (length(unique(x$Pop)) != length(which(!is.na(x$Pop)))) {
     warning("Population names are not unique")
@@ -84,13 +87,13 @@ Tg <- function(x = NULL,
           nlevels(x$Pop)^2 - nlevels(x$Pop)
         ) / 2),
         alternative = alternative,
-        sig.level = sig.level,
+        CI = CI,
         digits = digits,
         es = es
       )
     })
   tg <- do.call(rbind.data.frame, tg)
-  tg <- tibble::rownames_to_column(tg, var = "populations")
+  tg <- rown_col(tg, var = "populations")
 
   # Pairwise comparisons and corrplot ---------------------------------------
 
@@ -103,18 +106,18 @@ Tg <- function(x = NULL,
   if (isTRUE(letters)) {
     tg <-
       list(
-        "t.test" = tibble::as_tibble(tg),
-        "pairwise letters" = tibble::rownames_to_column(
+        "t.test" = tg,
+        "pairwise letters" = rown_col(
           data.frame(
             "letters" = multcompView::multcompLetters(pval,
-              threshold = sig.level
+              threshold = CI
             )[[1]]
           ),
           var = "populations"
         )
       )
   } else {
-    tg <- tibble::as_tibble(tg)
+    tg <- tg
   }
   if (!is.logical(plot)) {
     stop("plot should be either TRUE or FALSE")
@@ -125,7 +128,7 @@ Tg <- function(x = NULL,
       corrplot::corrplot(
         corr = pmatrix,
         p.mat = pmatrix,
-        sig.level = sig.level,
+        sig.level = 1 - CI,
         number.digits = digits,
         is.corr = FALSE,
         ...
