@@ -1,11 +1,12 @@
 test_that("accu_model", {
+  testthat::skip_if_not_installed("e1071")
   testthat::expect_true(round(
     accu_model(
       f = Sex ~ GOL + NOL + BNL,
       x = Howells,
       y = Howells,
       byPop = FALSE
-    )[[3]][[1]],
+    )[[2]][[3]][[1]],
     3
   ) == 0.789)
 
@@ -16,38 +17,16 @@ test_that("accu_model", {
       y = Howells,
       byPop = TRUE,
       Pop = 2
-    )[[1]][[3]][[1]],
+    )[[2]][[1]][[3]][[1]],
     3
   ) == 0.91)
-
-  vdiffr::expect_doppelganger(
-    title = "Single plot",
-    fig = accu_model(
-      f = Sex ~ GOL + NOL + BNL,
-      x = Howells,
-      y = Howells,
-      byPop = FALSE,
-      plot = TRUE
-    )[[1]]
-  )
-  vdiffr::expect_doppelganger(
-    title = "Pop plot",
-    fig = accu_model(
-      f = Sex ~ GOL + NOL + BNL,
-      x = Howells,
-      y = Howells,
-      byPop = TRUE,
-      Pop = 2,
-      plot = TRUE
-    )[[1]]
-  )
   set.seed(123)
   testthat::expect_true(round(
     accu_model(
       f = Sex ~ GOL + NOL + BNL,
       x = Howells,
       byPop = FALSE
-    )[[3]][[1]],
+    )[[2]][[3]][[1]],
     3
   ) == 0.811)
   set.seed(123)
@@ -57,9 +36,9 @@ test_that("accu_model", {
       x = Howells,
       byPop = TRUE,
       Pop = 2
-    )[[1]][[3]][[1]],
+    )[[2]][[3]][[3]][[1]],
     3
-  ) == 0.909)
+  ) == 0.762)
   testthat::expect_error(
     accu_model(
       f = Sex ~ GOL + NOL + BNL,
